@@ -13,7 +13,9 @@
             1 - filename does not match pattern
 */
 
-int  CheckFilePattern(char *FileName, compression_struct *cs)
+int  CheckFilePattern(FileName, cs)
+  char *FileName;
+  compression_struct *cs;
 {
   switch(cs->Type)
   {
