@@ -11,7 +11,8 @@
                  returns: 29
 */
 
-int  ParseFileName(char *FileName)
+int  ParseFileName(FileName)
+  char *FileName;
 {
 char *wrkptr;
 
